==> remmina_1.4.11+dfsg.orig.tar.xz: Remmina-v1.4.11/README.md <==
[![](https://img.shields.io/liberapay/receives/Remmina.svg?logo=liberapay)](https://liberapay.com/Remmina/donate)
[![](https://img.shields.io/liberapay/patrons/remmina.svg?logo=liberapay)](https://liberapay.com/Remmina/donate)
[![Build Status](https://gitlab.com/Remmina/Remmina/badges/master/pipeline.svg)](https://gitlab.com/Remmina/Remmina/pipelines)
[![Translation status](https://hosted.weblate.org/widgets/remmina/-/remmina/svg-badge.svg)](https://hosted.weblate.org/engage/remmina/?utm_source=widget)
[![remmina](https://snapcraft.io//remmina/badge.svg)](https://snapcraft.io/remmina)

## Remmina remote desktop client

*Use other desktops remotely, from a tiny screen or large monitors.*


* RDP, VNC, SPICE, NX, XDMCP, SSH and EXEC network protocols are supported.
* Written in GTK, with a port to Qt underway. 
* Released as "remmina" (the main program) and "remmina-plugins".

### Installation

[How to install Remmina](https://remmina.org/how-to-install-remmina/),
editable on [the wiki](https://gitlab.com/Remmina/Remmina/wikis/home).

### Configuration

Set up everything from the graphical interface, or from $HOME/.remmina or $HOME/.config/remmina

### Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new merge request

There are [other ways](CONTRIBUTING.md) to contribute too, get in contact on IRC (#remmina on freenode), or send an e-mail to the [mailing list](https://lists.remmina.org/listinfo/users).

### Donations

This is the website [donation page](https://remmina.org/wp/donations/).
[THANKS](THANKS.md) is a list of supporters.

### Authors

Maintained by [Antenore Gatta](https://gitlab.com/antenore), [Giovanni Panozzo](https://gitlab.com/giox069) and [Dario Cavedon](https://gitlab.com/ic3d).
Add yourself in [AUTHORS](AUTHORS) if you have contributed.

### Resources

 * [Website](https://www.remmina.org/)
 * IRC room on freenode.net, in the #remmina channel, you can also use a [web client](https://kiwiirc.com/client/irc.freenode.net/?nick=remminer|?#remmina/).

### License

Copylefted libre software, licensed [GPLv2+](https://gitlab.com/Remmina/Remmina/blob/master/COPYING).

Initially developed by [Vic Lee](https://github.com/llyzs).

==> remmina_1.4.25+dfsg.orig.tar.xz: Remmina-v1.4.25/README.md <==
[![](https://img.shields.io/liberapay/receives/Remmina.svg?logo=liberapay)](https://liberapay.com/Remmina/donate)
[![](https://img.shields.io/liberapay/patrons/remmina.svg?logo=liberapay)](https://liberapay.com/Remmina/donate)
[![](https://opencollective.com/remmina/tiers/badge.svg)](https://opencollective.com/remmina)
[![Build Status](https://gitlab.com/Remmina/Remmina/badges/master/pipeline.svg)](https://gitlab.com/Remmina/Remmina/pipelines)
[![Translation status](https://hosted.weblate.org/widgets/remmina/-/remmina/svg-badge.svg)](https://hosted.weblate.org/engage/remmina/?utm_source=widget)
[![remmina](https://snapcraft.io//remmina/badge.svg)](https://snapcraft.io/remmina)

## Remmina remote desktop client

*Use other desktops remotely, from a tiny screen or large monitors.*


* RDP, VNC, SPICE, X2Go, SSH, WWW (HTTP protocol) and EXEC network protocols are supported.
* Written in GTK, with a port to Qt underway.
* Released as "remmina" (the main program) and "remmina-plugins".

### Installation

[How to install Remmina](https://remmina.org/how-to-install-remmina/),
editable on [the wiki](https://gitlab.com/Remmina/Remmina/wikis/home).

### Configuration

Set up everything from the graphical interface, or from $HOME/.config/remmina

### Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new merge request

There are [other ways](CONTRIBUTING.md) to contribute too, get in contact on IRC (#remmina on libera.chat), or send an e-mail to the [mailing list](https://lists.remmina.org/listinfo/users).

### Donations

This is the website [donation page](https://remmina.org/wp/donations/).
[THANKS](THANKS.md) is a list of supporters.

### Authors

Maintained by [Antenore Gatta](https://gitlab.com/antenore), [Giovanni Panozzo](https://gitlab.com/giox069) and [Dario Cavedon](https://gitlab.com/ic3d).
Add yourself in [AUTHORS](AUTHORS) if you have contributed.

### Resources

 * [Website](https://www.remmina.org/)
 * IRC room on libera.chat, in the #remmina channel, you can also use a [web client](https://web.libera.chat/?nick=remminer|?#remmina).

### License

Copylefted libre software, licensed [GPLv2+](https://gitlab.com/Remmina/Remmina/blob/master/COPYING).

Initially developed by [Vic Lee](https://github.com/llyzs).
